==> jc-1.4.0.tar.gz: scm/scmaddException.h <==
// class scm.scmaddException

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 1c09466231201dc3 scm_scmaddException

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmaddException_H_
#define _JC_scm_scmaddException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmaddException$sub_refs	_jc_scm_scmaddException$sub_refs;
typedef struct _jc_scm_scmaddException$sub_nonrefs	_jc_scm_scmaddException$sub_nonrefs;
typedef struct _jc_scm_scmaddException$refs	_jc_scm_scmaddException$refs;
typedef struct _jc_scm_scmaddException$nonrefs	_jc_scm_scmaddException$nonrefs;
typedef struct _jc_scm_scmaddException$object	_jc_scm_scmaddException$object;

typedef const struct _jc_scm_scmaddException$vmethods	_jc_scm_scmaddException$vmethods;
typedef const struct _jc_scm_scmaddException$vtable	_jc_scm_scmaddException$vtable;
typedef const struct _jc_scm_scmaddException$vtype	_jc_scm_scmaddException$vtype;

// Constructors
extern void _jc_scm_scmaddException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmaddException$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_scmaddException$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmaddException$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_scmaddException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmaddException$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_scmaddException$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmaddException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmaddException$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmaddException$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmaddException$object *);
};

// Vtable
struct _jc_scm_scmaddException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmaddException$vmethods	scm_scmaddException;
};

// Vtype
struct _jc_scm_scmaddException$vtype {
	_jc_type			type;
	_jc_scm_scmaddException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmaddException$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmaddException$refs {
    _jc_scm_scmaddException$sub_refs	scm_scmaddException;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmaddException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmaddException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmaddException$sub_nonrefs	scm_scmaddException;
};

// Object instance structure
struct _jc_scm_scmaddException$object {
	_jc_scm_scmaddException$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmaddException$vtype	*vtype;
	_jc_scm_scmaddException$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmaddException$vtype _jc_scm_scmaddException$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmaddException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmaddException$class_object;

#endif	/* _JC_scm_scmaddException_H_ */

==> jc-1.4.6.tar.gz: scm/scmaddException.h <==
// class scm.scmaddException

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure
// @dep_class 1c09466231201dc3 scm_scmaddException

// header file dependencies
// @dep_header scm_Procedure

#include "scm/Procedure.h"

#ifndef _JC_scm_scmaddException_H_
#define _JC_scm_scmaddException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_scmaddException$sub_refs	_jc_scm_scmaddException$sub_refs;
typedef struct _jc_scm_scmaddException$sub_nonrefs	_jc_scm_scmaddException$sub_nonrefs;
typedef struct _jc_scm_scmaddException$refs	_jc_scm_scmaddException$refs;
typedef struct _jc_scm_scmaddException$nonrefs	_jc_scm_scmaddException$nonrefs;
typedef struct _jc_scm_scmaddException$object	_jc_scm_scmaddException$object;

typedef const struct _jc_scm_scmaddException$vmethods	_jc_scm_scmaddException$vmethods;
typedef const struct _jc_scm_scmaddException$vtable	_jc_scm_scmaddException$vtable;
typedef const struct _jc_scm_scmaddException$vtype	_jc_scm_scmaddException$vtype;

// Constructors
extern void _jc_scm_scmaddException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_scmaddException$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_scmaddException$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_scmaddException$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_scmaddException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_scmaddException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_scmaddException$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_scmaddException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_scmaddException$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_scmaddException$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_scmaddException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_scmaddException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
	_jc_scm_scmaddException$vmethods	scm_scmaddException;
};

// Vtype
struct _jc_scm_scmaddException$vtype {
	_jc_type			type;
	_jc_scm_scmaddException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_scmaddException$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_scmaddException$refs {
    _jc_scm_scmaddException$sub_refs	scm_scmaddException;
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_scmaddException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_scmaddException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
    _jc_scm_scmaddException$sub_nonrefs	scm_scmaddException;
};

// Object instance structure
struct _jc_scm_scmaddException$object {
	_jc_scm_scmaddException$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_scmaddException$vtype	*vtype;
	_jc_scm_scmaddException$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_scmaddException$vtype _jc_scm_scmaddException$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_scmaddException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_scmaddException$class_object;

#endif	/* _JC_scm_scmaddException_H_ */
